Okulary ochronne - Janser
Description: Uniwersalne okulary ochronne. Możliwość regulowania długości i nachylenia oprawek. Jasne szkła ze wzmocnioną powłoką. Chronią oczy przed rozpryskującymi się materiałami.

Dodaj do ulubionych

- Opis
- Opinie (0)

## Opis

Uniwersalne okulary ochronne.

Możliwość regulowania długości i nachylenia oprawek.

Jasne szkła ze wzmocnioną powłoką.

Chronią oczy przed rozpryskującymi się materiałami.

0,0
Na podstawie 0 recenzji

5 gwiazdek |  | 0%
4 gwiazdki |  | 0%
3 gwiazdki |  | 0%
2 gwiazdki |  | 0%
1 gwiazdka |  | 0%

0 z 0 recenzji

Przepraszamy, żadne recenzje nie pasują do twoich aktualnych wyborów

# Okulary ochronne

46,10zł netto + VAT

Uniwersalne okulary ochronne.
Możliwość regulowania długości i nachylenia oprawek.
Jasne szkła ze wzmocnioną powłoką.
Chronią oczy przed rozpryskującymi się materiałami.

Zobacz więcej

Dostępny

ilość Okulary ochronne
SKU: 440-060-000 Kategorie: Materiały eksploatacyjne, Odzież robocza i BHP Tag: usuwanie subitu
×

## Zadaj pytanie

Imię *
Wiadomość *
Zgoda na przetwarzanie danych osobowych *

Wyrażam zgodę na przetwarzanie moich danych osobowych zgodnie z zasadami określonymi w Polityce prywatności i cookies.

- Opis
- Opinie (0)

## Opis

Uniwersalne okulary ochronne.

Możliwość regulowania długości i nachylenia oprawek.

Jasne szkła ze wzmocnioną powłoką.

Chronią oczy przed rozpryskującymi się materiałami.

0,0
Na podstawie 0 recenzji

5 gwiazdek |  | 0%
4 gwiazdki |  | 0%
3 gwiazdki |  | 0%
2 gwiazdki |  | 0%
1 gwiazdka |  | 0%

0 z 0 recenzji

Przepraszamy, żadne recenzje nie pasują do twoich aktualnych wyborów

### Polecane produkty

Niezbędnik instalatora

## Maska ochronna FFP1

Nowoczesna konstrukcja maski optymalizuje oddychanie pozostawiając więcej miejsca do dyspozycji w obszarze nosa niż w zwykłych maskach maski.

295,35zł netto + VAT
Dodaj do koszyka

## Maseczki ochronne jednorazowe KN95/FFP2 (op. 5 szt.)

Maska ochronna o wysokiej skuteczności i klasie ochrony FFP2 zapewnia ochronę przed pyłami, bakteriami, wirusami i mniej toksycznymi substancjami.

75,60zł netto + VAT
Dodaj do koszyka

## Nakładki zabezpieczające na obuwie

Zestaw, za pomocą którego można łatwo i szybko nakleić nakładki na czubki butów.

50,49zł netto + VAT
Dodaj do koszyka

## Uchwyt do filtrów (op. 10 szt.)

Uchwyt do filtrów (op. 10 szt.).

262,58zł netto + VAT
Dodaj do koszyka

## Bądź na bieżąco, wyprzedź rynkową konkurencję!

Subskrybuj nasz newsletter i zyskaj dostęp do praktycznych porad dla specjalistów od podłóg i informacji o nowościach z naszej oferty.

Wyrażam zgodę na przetwarzanie moich danych osobowych zgodnie z zasadami określonymi w Polityce prywatności i Cookies

Polecają nas!

Sprawdź, dlaczego

5 na 5
na portalu Facebook

Poznaj więcej opinii

Obserwuj

Odwiedź nasze profile
społecznościowe!

Skontaktuj się z nami
- w najwygodniejszej formie!

Przejdź do kontaktu

Janser Polska Sp. z o.o.
ul. Powstańców Wielkopolskich 5
64-111 Lipno k. Leszna

info@janser.pl
(+48) 600 033 044 (+48) 65 534 06 80

#### Zakupy

- Moje konto
- Zamówienie
- Regulamin
- Polityka prywatności i Cookies

#### Warunki dostawy

- Jak szybko dostarczymy Ci zamówiony towar?
- Ile wynosi koszt dostawy?
- Jak zapłacić za towar?

#### Serwis i gwarancja

- Serwis JANSER i w Twojej
  firmie wszystko działa!
- Zgłoś urządzenie do naprawy
- Nasze lokalizacje

Dodano do koszyka
Przejdź do koszyka

#### Twój koszyk (0)

Brak produktów w koszyku.